const Mesa = require('vendor/Mesa.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {

  /**
   * Mesa Script
   *
   * @param {object} payload The payload data
   * @param {object} context Additional context about this task
   */
  script = (payload, context) => {
    let vars = context.steps;
    let product = vars.shopify;
    let variant = vars.loop;

    if (!product.image || ! product.image.src) {
      Mesa.output.next({});
      return;
    }

    let options = {
      "headers": {
        "Content-Type": "application\/json",
        "Authorization": "Bearer " + Mesa.credential.get('airtable'),
      }
    }

    let airtableProductId = context.steps.custom.record.id;
    let base = context.steps.transform.base;
    let table = 'Products';
    let url = 'https://api.airtable.com/v0/' + base + '/' + table + '/' + airtableProductId;

    let data = {
      "fields": {
        "Images": [
          {
            "url": product.image.src,
          }
        ]
      },
    }
    
    let result = Mesa.request.patch(url, data, options);
    Mesa.log.info('result', result);
    if (result.error) {
        throw new Error("Airtable error: " + JSON.stringify(result.error))
    }

    Mesa.output.next(result);
  }
}
